django-payments
===============

This library is a Django app for handling payments with a few different payment
providers.

Contents:

.. toctree::
   :maxdepth: 2
   :numbered:

   install.rst
   usage.rst
   refund.rst
   preauth.rst
   modules.rst
